---
milena/ChangeLog | 4 ++++
milena/mln/io/{tiff => vtk}/all.hh | 16 ++++++++--------
2 files changed, 12 insertions(+), 8 deletions(-)
copy milena/mln/io/{tiff => vtk}/all.hh (80%)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index d850e40..41c681c 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,3 +1,7 @@
+2010-07-27 Roland Levillain <roland(a)lrde.epita.fr>
+
+ * mln/io/vtk/all.hh: New.
+
2010-06-24 Roland Levillain <roland(a)lrde.epita.fr>
Add a specific (temporary) VTK output routine for binary mesh images.
diff --git a/milena/mln/io/tiff/all.hh b/milena/mln/io/vtk/all.hh
similarity index 80%
copy from milena/mln/io/tiff/all.hh
copy to milena/mln/io/vtk/all.hh
index 55e9712..6ff98ce 100644
--- a/milena/mln/io/tiff/all.hh
+++ b/milena/mln/io/vtk/all.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2009 EPITA Research and Development Laboratory (LRDE)
+// Copyright (C) 2010 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -23,11 +23,11 @@
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.
-#ifndef MLN_IO_TIFF_ALL_HH
-# define MLN_IO_TIFF_ALL_HH
+#ifndef MLN_IO_VTK_ALL_HH
+# define MLN_IO_VTK_ALL_HH
/// \file
/// \brief Inclusion of all TIFF I/O routines.
namespace mln
@@ -35,12 +35,12 @@ namespace mln
namespace io
{
- /// Namespace of tiff input/output handling.
- namespace tiff {}
+ /// Namespace of vtk input/output handling.
+ namespace vtk {}
}
}
-# include <mln/io/tiff/load.hh>
+# include <mln/io/vtk/save.hh>
-#endif // ! MLN_IO_TIFF_ALL_HH
+#endif // ! MLN_IO_VTK_ALL_HH
@@ -23,11 +23,11 @@
/// \file
-/// \brief Inclusion of all TIFF I/O routines.
+/// \brief Inclusion of all VTK I/O routines.
namespace mln
--
1.5.6.5
Show replies by date